<?php

/* @var $this \yii\web\View */
/* @var $token */
/* @var $tasks */
/* @var $listId */

use yii\helpers\Url;
use yii\helpers\Html;

$this->title = 'Список задач';

?>
<div class="panel panel-primary">
	<div class="panel-heading">
		<b>Постоянная ссылка на ваши задачи</b>
	</div>
	<div class="panel-body">
		<input value="<?= Html::encode(Url::to(['todo/list', 'token' => $token], true)) ?>" type="text" class="form-control" readonly>
	</div>
</div>

<div class="panel panel-primary">
	<div class="panel-heading">
		<b>Добавить новую задачу</b>
	</div>
	<div class="panel-body">
		<input id="new_task_description" class="form-control" placeholder="Введите описание задачи">
	</div>
	<div class="panel-footer text-right">
		<button id="add_new_task" class="btn btn-primary">
			Добавить
		</button>
	</div>
</div>

<div class="panel panel-primary">
	<div class="panel-heading">
		<b>Список задач</b>
	</div>
	<div class="panel-body">
        <table id="tasks_table" cellpadding="0" cellspacing="0">
            <tbody>
            <?php if($tasks): ?>

                <?php foreach($tasks as $task):?>
                    <tr data-task-id="<?= $task->id ?>">
                        <td>
                            <input type="checkbox" class="state_input" <?= $task->finished_at ? ' checked' : '' ?>>
                        </td>
                        <td style="padding-right: 0">
                            <input type="text" class="form-control description_input<?= $task->finished_at ? ' finished' : '' ?>" value="<?= Html::encode($task->description) ?>">
                        </td>
                        <td style="padding-left: 0">
                            <button class="btn btn-primary save_input">Сохранить</button>
                        </td>
                        <td>
                            <button class="btn btn-danger delete_input">Удалить</button>
                        </td>
                    </tr>
                    <tr>
                        <td></td>
                        <td colspan="2" class="datetime">Создана <?= $task->date ?></td>
                        <td></td>
                    </tr>
                <?php endforeach; ?>
            <?php endif ?>
            <tr id="empty_tasks" style="<?= $tasks ? 'display: none' : '' ?>">
                <td colspan="4">Нет задач</td>
            </tr>
            </tbody>
        </table>
	</div>
</div>

<?php

$addTaskUrl = Url::to(['todo/add-task'], true);
$editDescriptionUrl = Url::to(['todo/edit-description'], true);
$finisTaskUrl = Url::to(['todo/finish-task'], true);
$unfinisTaskUrl = Url::to(['todo/unfinish-task'], true);
$deleteTaskUrl = Url::to(['todo/delete-task'], true);

$taskCount = $tasks ? count($tasks) : 0;

$this->registerJs(<<<JS

// URL для AJAX запросов
var addTaskUrl = '$addTaskUrl';
var editDescriptionUrl = '$editDescriptionUrl';
var finishTaskUrl = '$finisTaskUrl';
var unfinishTaskUrl = '$unfinisTaskUrl';
var deleteTaskUrl = '$deleteTaskUrl';

var taskCount = $taskCount;
var listId = $listId;
var listTable = jQuery('#tasks_table');
var emptyTasks = jQuery('#empty_tasks');

var newTaskDescriptionInput = jQuery('#new_task_description');
jQuery('#add_new_task').on('click', function(){
    var description = newTaskDescriptionInput.val();
    newTaskDescriptionInput.val('');
    jQuery.post(addTaskUrl, {list_id: listId, description: description}).done(function(result){
        if(result.success) {
            var newTask = $('<tr data-task-id="' + result.task_id + '">' +
            '<td>' +
            '<input type="checkbox" class="state_input">' +
            '</td>' +
            '<td style="padding-right: 0">' +
            '<input type="text" class="form-control description_input" value="' + description + '">' +
            '</td>' +
            '<td style="padding-left: 0">' +
            '<button class="btn btn-primary save_input">Сохранить</button>' +
            '</td>' +
            '<td>' +
            '<button class="btn btn-danger delete_input">Удалить</button>' +
            '</td>' +
            '</tr>'+
            '<tr>' +
            '<td></td>' +
            '<td colspan="2" class="datetime">Создана ' + result.date + '</td>' +
            '<td></td>' +
            '</tr>'
            );
            listTable.find('tbody').prepend(newTask);
            ++taskCount;
            emptyTasks.hide();
       
        }
     
    });
});

// изменение состояния списка
listTable.on('change', '.state_input', function(){
    var parentTr = jQuery(this).parents('tr').first();
    var taskId = parentTr.data('taskId');
    var descriptionInput = parentTr.find('.description_input');
    var state = jQuery(this).is(':checked');
    if (state) {
        jQuery.post(finishTaskUrl, {task_id: taskId}).done(function(){
            descriptionInput.addClass('finished');
        });
    } else {
        jQuery.post(unfinishTaskUrl, {task_id: taskId}).done(function(){
            descriptionInput.removeClass('finished');
        });
    }
});

// изменение описания задачи
listTable.on('click', '.save_input', function(){
    if(!confirm('Изменить описание задачи?')) return;
    var parentTr = jQuery(this).parents('tr').first();
    var taskId = parentTr.data('taskId');
    var descriptionInput = parentTr.find('.description_input');
    jQuery.post(editDescriptionUrl, {task_id: taskId, description: descriptionInput.val()});
});

// удаление задачи
listTable.on('click', '.delete_input', function(){
    if(!confirm('Удалить задачу?')) return;
    var parentTr = jQuery(this).parents('tr').first();
    var taskId = parentTr.data('taskId');
    jQuery.post(deleteTaskUrl, {task_id: taskId});
    parentTr.next().remove();
    parentTr.remove();
    --taskCount;
    console.log(taskCount);
    if(taskCount <= 0) {
        emptyTasks.show();
    }
});

JS
);