<?php

namespace app\controllers;

use Yii;
use yii\web\Controller;
use yii\web\Response;
use yii\helpers\Json;
use app\models\UserModel;
use yii\web\UnauthorizedHttpException;

class UserController extends Controller
{

    public $enableCsrfValidation = false;

    private function getRequestData()
    {
        $body = Yii::$app->request->getRawBody();
        return Json::decode($body);
    }

    public function actionGet()
    {
        Yii::$app->response->format = Response::FORMAT_JSON;
        $data = $this->getRequestData();
        /* @var $user UserModel */
        $user = UserModel::findOne(['id' => $data['user_id'], 'auth_key' => $data['auth_key'], 'deleted' => 0]);
        if ($user) {
            $result = [];
            $result['user_id'] = $user->id;
            $result['auth_key'] = $user->auth_key;
            // необходимая для получения информация о пользователе
            if(isset($data['needle_params']) && is_array($data['needle_params'])) {
                if(in_array('last_request_datetime', $data['needle_params'])) {
                    $result['last_request_datetime'] = date('d.m.Y H:i:s', $user->getLastRequestTimestamp());
                }
                if(in_array('last_request_timestamp', $data['needle_params'])) {
                    $result['last_request_timestamp'] = $user->getLastRequestTimestamp();
                }
                if(in_array('requests_count_per_day', $data['needle_params'])) {
                    $result['requests_count_per_day'] = $user->getRequestDaysCount();
                }
                if(in_array('requests_count_periodical', $data['needle_params'])) {
                    $result['requests_count_periodical'] = $user->getRequestDaysPeriodCount();
                }
            }
            // необходимые данные пользователя для выборки
            if(isset($data['needle_data']) && is_array($data['needle_data'])) {
                $result['data'] = $user->getData($data['needle_data']);
            }
            return $result;

        } else {
            throw new UnauthorizedHttpException();
        }
    }

    public function actionUpdateData()
    {
        Yii::$app->response->format = Response::FORMAT_JSON;
        $data = $this->getRequestData();
        /* @var $user UserModel */
        $user = UserModel::findOne(['id' => $data['user_id'], 'auth_key' => $data['auth_key'], 'deleted' => 0]);
        if ($user) {
            $user->setData($data['data']);

        } else {
            throw new UnauthorizedHttpException();
        }
    }

    public function actionCreate()
    {
        Yii::$app->response->format = Response::FORMAT_JSON;
        $model = new UserModel();
        $model->generateAuthKey();
        $model->save(false);
        return [
            'user_id' => $model->id,
            'auth_key' => $model->auth_key
        ];
    }

    public function actionDelete()
    {
        Yii::$app->response->format = Response::FORMAT_JSON;
        $data = $this->getRequestData();
        $user = UserModel::findOne(['id' => $data['user_id'], 'auth_key' => $data['auth_key'], 'deleted' => 0]);
        if ($user) {
            $user->delete();
        } else {
            throw new UnauthorizedHttpException();
        }
    }


}